**Example 1: 将未绑定套餐的站点绑定到目标套餐**



Input: 

```
tccli teo BindZoneToPlan --cli-unfold-argument  \
    --ZoneId zone-xxyyyzzz \
    --PlanId edgeone-qqqwwweee
```

Output: 
```
{
    "Response": {
        "RequestId": "fd9d86df-b7e8-4469-b928-18cb7fd145641"
    }
}
```

